package com.silence.network;

import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleOwner;
import com.silence.network.listener.CallBackLis;
import com.silence.network.utils.SimpleObserver;
import com.uber.autodispose.AutoDispose;
import com.uber.autodispose.ObservableSubscribeProxy;
import com.uber.autodispose.android.lifecycle.AndroidLifecycleScopeProvider;
import io.reactivex.Observable;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.schedulers.Schedulers;

public class HttpCall {
    private static final String TAG = "HttpCall";

    public static <T> void doCall(LifecycleOwner lifecycleOwner, Observable<ResponseModel<T>> observable, final CallBackLis<T> callBackLis, final String str) {
        if (observable == null || callBackLis == null) {
            throw new IllegalArgumentException("observable或callBackLis为空");
        }
        AnonymousClass1 r0 = new SimpleObserver<ResponseModel<T>>() {
            /* class com.silence.network.HttpCall.AnonymousClass1 */

            public void onNext(ResponseModel<T> responseModel) {
                try {
                    if (responseModel.getCode() == 0) {
                        CallBackLis.this.onSuccess(str, responseModel.getData());
                    } else {
                        CallBackLis.this.onFailure(str, responseModel.getMsg());
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                    CallBackLis.this.onFailure(str, "解析错误！");
                }
            }

            @Override // io.reactivex.Observer, com.silence.network.utils.SimpleObserver
            public void onError(Throwable th) {
                CallBackLis.this.onFailure(str, HttpStatusCode.handleException(th));
            }
        };
        if (lifecycleOwner == null) {
            observable.subscribeOn(Schedulers.newThread()).unsubscribeOn(Schedulers.newThread()).observeOn(AndroidSchedulers.mainThread()).subscribe(r0);
        } else {
            ((ObservableSubscribeProxy) observable.subscribeOn(Schedulers.newThread()).unsubscribeOn(Schedulers.newThread()).observeOn(AndroidSchedulers.mainThread()).as(AutoDispose.autoDisposable(AndroidLifecycleScopeProvider.from(lifecycleOwner, Lifecycle.Event.ON_DESTROY)))).subscribe(r0);
        }
    }

    public static <T> void doCallWithoutIntercept(LifecycleOwner lifecycleOwner, Observable<T> observable, final CallBackLis<T> callBackLis, final String str) {
        if (observable == null || callBackLis == null) {
            throw new IllegalArgumentException("observable或callBackLis为空");
        }
        AnonymousClass2 r0 = new SimpleObserver<T>() {
            /* class com.silence.network.HttpCall.AnonymousClass2 */

            @Override // io.reactivex.Observer, com.silence.network.utils.SimpleObserver
            public void onNext(T t) {
                if (t != null) {
                    try {
                        CallBackLis.this.onSuccess(str, t);
                    } catch (Exception e) {
                        e.printStackTrace();
                        CallBackLis.this.onFailure(str, "解析错误！");
                    }
                } else {
                    CallBackLis.this.onFailure(str, "请求数据异常！");
                }
            }

            @Override // io.reactivex.Observer, com.silence.network.utils.SimpleObserver
            public void onError(Throwable th) {
                CallBackLis.this.onFailure(str, HttpStatusCode.handleException(th));
            }
        };
        if (lifecycleOwner == null) {
            observable.subscribeOn(Schedulers.newThread()).unsubscribeOn(Schedulers.newThread()).observeOn(AndroidSchedulers.mainThread()).subscribe(r0);
        } else {
            ((ObservableSubscribeProxy) observable.subscribeOn(Schedulers.newThread()).unsubscribeOn(Schedulers.newThread()).observeOn(AndroidSchedulers.mainThread()).as(AutoDispose.autoDisposable(AndroidLifecycleScopeProvider.from(lifecycleOwner, Lifecycle.Event.ON_DESTROY)))).subscribe(r0);
        }
    }
}
