package com.uber.autodispose.android;

import io.reactivex.exceptions.Exceptions;
import io.reactivex.functions.BooleanSupplier;
import java.util.Objects;

public final class AutoDisposeAndroidPlugins {
    static volatile boolean lockdown;
    private static volatile BooleanSupplier onCheckMainThread;

    private AutoDisposeAndroidPlugins() {
    }

    public static void lockdown() {
        lockdown = true;
    }

    public static boolean isLockdown() {
        return lockdown;
    }

    public static void setOnCheckMainThread(BooleanSupplier booleanSupplier) {
        if (!lockdown) {
            onCheckMainThread = booleanSupplier;
            return;
        }
        throw new IllegalStateException("Plugins can't be changed anymore");
    }

    public static boolean onCheckMainThread(BooleanSupplier booleanSupplier) {
        Objects.requireNonNull(booleanSupplier, "defaultChecker == null");
        BooleanSupplier booleanSupplier2 = onCheckMainThread;
        if (booleanSupplier2 != null) {
            return booleanSupplier2.getAsBoolean();
        }
        try {
            return booleanSupplier.getAsBoolean();
        } catch (Exception e) {
            throw Exceptions.propagate(e);
        }
    }

    public static void reset() {
        setOnCheckMainThread(null);
    }
}
