package com.uber.autodispose.lifecycle;

import com.uber.autodispose.AutoDisposePlugins;
import com.uber.autodispose.OutsideScopeException;
import io.reactivex.Completable;
import io.reactivex.CompletableSource;
import io.reactivex.Observable;
import io.reactivex.functions.Consumer;
import io.reactivex.functions.Predicate;
import java.util.Comparator;

public final class LifecycleScopes {
    private static final Comparator<Comparable<Object>> COMPARABLE_COMPARATOR = LifecycleScopes$$ExternalSyntheticLambda2.INSTANCE;

    private LifecycleScopes() {
        throw new InstantiationError();
    }

    public static <E> CompletableSource resolveScopeFromLifecycle(LifecycleScopeProvider<E> lifecycleScopeProvider) throws OutsideScopeException {
        return resolveScopeFromLifecycle((LifecycleScopeProvider) lifecycleScopeProvider, true);
    }

    public static <E> CompletableSource resolveScopeFromLifecycle(LifecycleScopeProvider<E> lifecycleScopeProvider, boolean z) throws OutsideScopeException {
        E peekLifecycle = lifecycleScopeProvider.peekLifecycle();
        CorrespondingEventsFunction<E> correspondingEvents = lifecycleScopeProvider.correspondingEvents();
        if (peekLifecycle != null) {
            try {
                return resolveScopeFromLifecycle(lifecycleScopeProvider.lifecycle(), correspondingEvents.apply(peekLifecycle));
            } catch (Exception e) {
                if (!z || !(e instanceof LifecycleEndedException)) {
                    return Completable.error(e);
                }
                Consumer<? super OutsideScopeException> outsideScopeHandler = AutoDisposePlugins.getOutsideScopeHandler();
                if (outsideScopeHandler != null) {
                    try {
                        outsideScopeHandler.accept((LifecycleEndedException) e);
                        return Completable.complete();
                    } catch (Exception e2) {
                        return Completable.error(e2);
                    }
                } else {
                    throw e;
                }
            }
        } else {
            throw new LifecycleNotStartedException();
        }
    }

    public static <E> CompletableSource resolveScopeFromLifecycle(Observable<E> observable, E e) {
        return resolveScopeFromLifecycle(observable, e, e instanceof Comparable ? COMPARABLE_COMPARATOR : null);
    }

    static /* synthetic */ boolean lambda$resolveScopeFromLifecycle$0(Comparator comparator, Object obj, Object obj2) throws Exception {
        return comparator.compare(obj2, obj) >= 0;
    }

    public static <E> CompletableSource resolveScopeFromLifecycle(Observable<E> observable, E e, Comparator<E> comparator) {
        Predicate<? super E> predicate;
        if (comparator != null) {
            predicate = new LifecycleScopes$$ExternalSyntheticLambda1(comparator, e);
        } else {
            predicate = new LifecycleScopes$$ExternalSyntheticLambda0(e);
        }
        return observable.skip(1).takeUntil(predicate).ignoreElements();
    }
}
